@@ -31,8 +31,8 @@ class FifteenPuzzlePlugin : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 
 public:
-    virtual void registerTypes(const char* uri);
-    virtual void initializeEngine(QQmlEngine * engine, const char * uri);
+    void registerTypes(const char* uri) Q_DECL_OVERRIDE;
+    void initializeEngine(QQmlEngine * engine, const char * uri) Q_DECL_OVERRIDE;
 
 };
 
