@@ -23,7 +23,7 @@
 
 #include <QUrl>
 #include <QObject>
-#include <QJsonObject>
+#include <QVariantMap>
 
 class QuicklaunchPrivate : public QObject
 {
@@ -32,8 +32,9 @@ class QuicklaunchPrivate : public QObject
 public:
     explicit QuicklaunchPrivate(QObject *parent = Q_NULLPTR);
 
-    Q_INVOKABLE QJsonObject launcherData(const QUrl &url);
+    Q_INVOKABLE QVariantMap launcherData(const QUrl &url);
     Q_INVOKABLE void openUrl(const QUrl &url);
+    Q_INVOKABLE void openExec(const QString &exec);
 
     Q_INVOKABLE void addLauncher(bool isPopup = false);
     Q_INVOKABLE void editLauncher(QUrl url, int index, bool isPopup = false);
