@@ -29,7 +29,7 @@ class ShowDesktopPlugin : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 
 public:
-    virtual void registerTypes(const char *uri);
+    void registerTypes(const char *uri) Q_DECL_OVERRIDE;
 };
 
 #endif // SHOWDESKTOPPLUGIN_H
