@@ -23,68 +23,64 @@
 
 #include <plasmaweather/weatherpopupapplet.h>
 
-class WeatherApplet : public WeatherPopupApplet
+class WeatherApplet : public Plasma::WeatherPopupApplet
 {
     Q_OBJECT
-    Q_PROPERTY(QString currentWeatherIconName READ currentWeatherIconName NOTIFY currentWeatherIconNameChanged)
-    Q_PROPERTY(QString currentWeatherToolTipMainText READ currentWeatherToolTipMainText NOTIFY currentWeatherToolTipMainTextChanged)
-    Q_PROPERTY(QString currentWeatherToolTipSubText READ currentWeatherToolTipSubText NOTIFY currentWeatherToolTipSubTextChanged)
-
     Q_PROPERTY(QVariantMap panelModel READ panelModel NOTIFY modelUpdated)
     Q_PROPERTY(QVariantList fiveDaysModel READ fiveDaysModel NOTIFY modelUpdated)
     Q_PROPERTY(QVariantList detailsModel READ detailsModel NOTIFY modelUpdated)
     Q_PROPERTY(QVariantList noticesModel READ noticesModel NOTIFY modelUpdated)
 
+    Q_PROPERTY(QVariantMap configuration READ configuration NOTIFY configurationChanged FINAL)
+    // used for making this information available to the config pages
+    Q_PROPERTY(bool needsToBeSquare MEMBER m_needsToBeSquare NOTIFY needsToBeSquareChanged FINAL)
+
 public:
     WeatherApplet(QObject *parent, const QVariantList &args);
-    ~WeatherApplet();
+    ~WeatherApplet() override;
 
 public: // Plasma::Applet API
     void init() override;
+    void configChanged() override;
 
 public:
-    QString currentWeatherIconName() const { return m_currentWeatherIconName; }
-    QString currentWeatherToolTipMainText() const { return m_currentWeatherToolTipMainText; }
-    QString currentWeatherToolTipSubText() const { return m_currentWeatherToolTipSubText; }
-
     QVariantMap panelModel() const { return m_panelModel; }
     QVariantList fiveDaysModel() const { return m_fiveDaysModel; }
     QVariantList detailsModel() const { return m_detailsModel; }
     QVariantList noticesModel() const { return m_noticesModel; }
+    QVariantMap configuration() const { return m_configuration; }
 
 Q_SIGNALS:
     void modelUpdated();
-    void currentWeatherIconNameChanged(const QString &currentWeatherIconName);
-    void currentWeatherToolTipMainTextChanged(const QString &currentWeatherToolTipMainText);
-    void currentWeatherToolTipSubTextChanged(const QString &currentWeatherToolTipSubText);
-
-public Q_SLOTS: // as expected by connected dataengines
-    void dataUpdated(const QString &source, const Plasma::DataEngine::Data &data);
+    void configurationChanged();
+    void needsToBeSquareChanged();
 
 public: // WeatherPopupApplet API
+    QVariantMap configValues() const override;
     void saveConfig(const QVariantMap& configChanges) override;
+    void dataUpdated(const QString &source, const Plasma::DataEngine::Data &data) override;
 
 private:
     bool isValidData(const QVariant &data) const;
-    void setCurrentWeatherIconName(const QString &currentWeatherIconName);
+    bool isValidData(const QString &data) const;
     void resetPanelModel();
     void updatePanelModel(const Plasma::DataEngine::Data &data);
     void updateFiveDaysModel(const Plasma::DataEngine::Data &data);
     void updateDetailsModel(const Plasma::DataEngine::Data &data);
     void updateNoticesModel(const Plasma::DataEngine::Data &data);
-    void updateToolTip();
-    QString convertTemperature(KUnitConversion::Unit format, const QString &value,
+    QString convertTemperature(const KUnitConversion::Unit& format, float value,
+                               int type, bool rounded = false, bool degreesOnly = false);
+    QString convertTemperature(const KUnitConversion::Unit& format, const QVariant& value,
                                int type, bool rounded = false, bool degreesOnly = false);
 
 private:
-    QString m_currentWeatherIconName;
-    QString m_currentWeatherToolTipMainText;
-    QString m_currentWeatherToolTipSubText;
-
     QVariantMap m_panelModel;
     QVariantList m_fiveDaysModel;
     QVariantList m_detailsModel;
     QVariantList m_noticesModel;
+
+    QVariantMap m_configuration;
+    bool m_needsToBeSquare = false;
 };
 
 #endif
