@@ -37,7 +37,7 @@ QString DictionaryMatchEngine::lookupWord(const QString &word)
     m_lockers.insert(word, &data);
     m_wordLock.unlock();
 
-    QMetaObject::invokeMethod(this, "sourceAdded", Qt::QueuedConnection, Q_ARG(const QString&, QLatin1Char(':') + word));
+    QMetaObject::invokeMethod(this, "sourceAdded", Qt::QueuedConnection, Q_ARG(const QString&, word));
     QMutexLocker locker(&data.mutex);
     if (!data.waitCondition.wait(&data.mutex, 30 * 1000)) // Timeout after 30 seconds
         qDebug() << "The dictionary data engine timed out (word:" << word << ")";
@@ -73,7 +73,7 @@ void DictionaryMatchEngine::dataUpdated(const QString &source, const Plasma::Dat
         /* Because of QString's CoW semantics, we don't have to worry about
          * the overhead of assigning this to every item. */
         data->definition = definition;
-        data->waitCondition.notify_one();
+        data->waitCondition.wakeOne();
     }
     m_wordLock.unlock();
 }
